.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth documentation master file, created by
   sphinx-quickstart on Sun Feb  5 12:18:05 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

TotalDepth
===========================

TotalDepth is an Open Source, cross platform, software collection that processes petrophysical data from the oil field such as wireline logs.

If you are new here then have a look at some :ref:`TotalDepth-examples`. For more detail see :ref:`TotalDepth-intro`.

The `TotalDepth project <https://github.com/paulross/TotalDepth>`_ is currently at **Beta**, development version |version|, release version |release|. For the licence see here :ref:`licence_text`.

Contents
===============

.. toctree::
	:maxdepth: 2
	
	intro
	examples/examples
	installation
	howto/index_howto
	cmd_line_tools/index_cmd_line_tools
	usage
	tech/index_tech
	testing/index_test
	ref/index_ref
	TODO
	licence
	contributing
	glossary
	history

For many years this project was hosted by `Sourceforge <https://sourceforge.net/projects/TotalDepth/>`_. Thank you Sourceforge!

Indices and tables
=========================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

